@@ -94,10 +94,10 @@ class Emulator:
         #entry_file_dir = os.path.dirname(os.path.realpath(sys.argv[0]))
         #python 约定 package_name总是相对于入口脚本目录
         #package_name = os.path.relpath(cur_file_dir, entry_file_dir).replace("/", ".")
-        package_name ='sower_androidemu'
-        print(F'获取package_name目录{package_name}')
+        package_name ='sower_androidemu' # pip 打包失效
+        #print(F'获取package_name目录{package_name}')
         full_dirname = "%s/java/classes"%(cur_file_dir, )
-        print(F'获取full_dirname目录{full_dirname}')
+        #print(F'获取full_dirname目录{full_dirname}')
         preload_classes = set()
         for importer, mod_name, c in pkgutil.iter_modules([full_dirname]):
             import_name = ".java.classes.%s"%mod_name
